// ------------------------------------------------------------
// Header for trading system
// This is the C-like non-class version

#ifndef CUED_TEACH_TRADING_H
#define CUED_TEACH_TRADING_H

// Error codes
//
enum TrError {
   TE_OKAY = 0,
   TE_FAIL,
   TE_ALREADY_CONNECTED,
   TE_NOT_CONNECTED,
   TE_AUTH_FAILED,
   TE_TOO_EARLY,
   TE_TOO_LATE,
   TE_NO_FUNDS,
   TE_NO_STOCK,
   TE_NUM_ERROR_CODES
};

// Data set codes
//
enum TrDataSet {
   TEST1 = 1,
   TEST2,
   TEST3,
   TEST4,
   TEST5,
   TEST6,
   TEST7,
   TEST8,
   TEST9,
   TEST10,
   TEST11,
   TEST12,
   TEST13,
   TEST14,
   TEST15,
   TEST16,
   TEST17,
   TEST18,
   TEST19,
   TEST20,
   FINAL = -1
};

// Buy / sell codes
//
enum TrTransType {
   TT_SELL = -1,
   TT_PASS =  0,
   TT_BUY  =  1
};

// Initialise trading
//
TrError TE_InitialiseTrading(int data_set, int group, float& commission);
//
// in:		data_set	Which set of prices to use?
//		group		Lab Group Number
// out:         commission      flat-rate commission per transaction
//
// return:	TE_OKAY			trading session initialised
//		TE_ALREADY_CONNECTED
//		TE_AUTH_FAILED

// Get today's price
//
TrError TE_GetPrice(int day, float &price);
//
// in:		day		trading day, starting at 1
// out:		price		the price for today
//
// return:	TE_OKAY		price will be valid
//		TE_NOT_CONNECTED	you weren't trading anyway
//		TE_TOO_EARLY	cannot look into the future! - you must
//                               make a transaction before incrementing
//				 the day.

// Make a transaction
//
TrError TE_Trade(int type, int volume);
//
// in:		type		TT_BUY, TT_SELL or TT_PASS
//              volume          how many to buy or sell (ignored for TT_PASS)
//
// return:	TE_OKAY		transaction succeeded
//		TE_NOT_CONNECTED	you weren't trading anyway
//		TE_NO_FUNDS	you cannot afford to buy that many!
//		TE_NO_STOCK	you don't have that many to sell!
//		TE_TOO_LATE	you have already transacted today

// Finish trading
//
TrError TE_CloseTrading(float &balance, int &stock);
//
// out:		balance			at close of trading
//              stock                   held at close of trading
//
// return:      TE_OKAY			balance & stock are valid
//		TE_NOT_CONNECTED	you weren't trading anyway

// Get a meaningful error description as a string
//
const char *TE_ErrorString(int error_code);
//
// in:		error_code	as returned by other trading functions
//
// return:	a string (valid only until next call to TrErrorString)

#endif // NDEF CUED_TEACH_TRADING_H

// EOF
